DockerfileElementType

Enum DockerfileElementType 

pub enum DockerfileElementType {
Show 47 variants Identifier, String, Number, Whitespace, Newline, From, Run, Cmd, Label, Maintainer, Expose, Env, Add, Copy, Entrypoint, Volume, User, Workdir, Arg, Onbuild, Stopsignal, Healthcheck, Shell, As, None, Interval, Timeout, StartPeriod, Retries, Equal, Equals, Colon, Comma, Semicolon, Dollar, LeftBracket, RightBracket, LeftBrace, RightBrace, LeftParen, RightParen, Comment, Path, Root, Statement, Error, Eof,
}
Element types for the Dockerfile parser.

Variants



Identifier

An identifier.



String

A string literal.



Number

A numeric literal.



Whitespace

Whitespace.



Newline

A newline character.



From

FROM instruction.



Run

RUN instruction.



Cmd

CMD instruction.



Label

LABEL instruction.



Maintainer

MAINTAINER instruction.



Expose

EXPOSE instruction.



Env

ENV instruction.



Add

ADD instruction.



Copy

COPY instruction.



Entrypoint

ENTRYPOINT instruction.



Volume

VOLUME instruction.



User

USER instruction.



Workdir

WORKDIR instruction.



Arg

ARG instruction.



Onbuild

ONBUILD instruction.



Stopsignal

STOPSIGNAL instruction.



Healthcheck

HEALTHCHECK instruction.



Shell

SHELL instruction.



As

AS keyword.



None

No-op or placeholder.



Interval

interval keyword.



Timeout

timeout keyword.



StartPeriod

start-period keyword.



Retries

retries keyword.



Equal

Single equals sign =.



Equals

Double equals sign ==.



Colon

Colon :.



Comma

Comma ,.



Semicolon

Semicolon ;.



Dollar

Dollar sign $.



LeftBracket

Left bracket [.



RightBracket

Right bracket ].



LeftBrace

Left brace {.



RightBrace

Right brace }.



LeftParen

Left parenthesis (.



RightParen

Right parenthesis ).



Comment

A comment.



Path

A file path.



Root

The root of the Dockerfile.



Statement

A statement or instruction.



Error

An error element.



Eof

End of stream.

Implementations

Source

impl DockerfileElementType

pub fn is_instruction(&self) -> bool

Returns true if this element type is a Dockerfile instruction.

pub fn is_trivia(&self) -> bool

Returns true if this element type is a trivia element (whitespace, newline, or comment).